InputType

Enum InputType 

pub enum InputType {
Show 22 variants Text, Password, Email, Number, Tel, Url, Search, Date, Time, DatetimeLocal, Month, Week, Color, File, Hidden, Checkbox, Radio, Range, Submit, Reset, Button, Image,
}

Variants



Text



Password



Email



Number



Tel



Url



Search



Date



Time



DatetimeLocal



Month



Week



Color



File



Hidden



Checkbox



Radio



Range



Submit



Reset



Button



Image

Implementations

Source

impl InputType

pub fn as_str(&self) -> &'static str